# candour

Behavioral measurement for AI agents.

Part of the [epagogy](https://epagogy.ai) research programme.

> *candour* (n.) — the quality of being open, honest, and sincere.

## Status

Pre-alpha. Code coming soon.
